#
# spec file for package xsm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _distconfdir %{_prefix}%{_sysconfdir}
%endif
Name:           xsm
Version:        1.0.5
Release:        bp155.1.7
Summary:        X Session Manager
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Patch0:         n_UsrEtc.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xt) > 1.0.99
# default rsh command is ssh
Requires:       openssh
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xsm is a session manager. A session is a group of applications, each
of which has a particular state. xsm allows you to create arbitrary
sessions - for example, you might have a "light" session, a "development"
session, or an "xterminal" session. Each session can have its own set of
applications. Within a session, you can perform a "checkpoint" to save
application state, or a "shutdown" to save state and exit the session. When
you log back in to the system, you can load a specific session, and you can
delete sessions you no longer want to keep.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fi
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README
%dir %{_distconfdir}
%dir %{_distconfdir}/X11
%{_distconfdir}/X11/xsm/
%{_bindir}/xsm
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/XSm
%{_mandir}/man1/xsm.1%{?ext_man}

%changelog
* Mon Apr  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.5
  * bugfix release
* Fri Dec  3 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Thu Jul  2 2020 Stefan Dirsch <sndirsch@suse.com>
- n_UsrEtc.patch:
  * add /usr/etc/X11/xsm/system.xsm as fallback to
    /etc/X11/xsm/system.xsm (boo#1173059)
* Thu Apr  5 2018 sndirsch@suse.com
- Update to version 1.0.4
  * autogen.sh changes
  * configure: Drop AM_MAINTAINER_MODE
  * Print which option was in error along with usage message
  * Remove obsolete Imake SIGNALRETURNSINT
  * Drop CRAY support
  * Improve help messages & man page
  * Close file descriptors on exec.
* Tue Feb 26 2013 zaitor@opensuse.org
- Update to version 1.0.3:
  + Use mode_t, not int, for umask return/argument value.
  + Use standard autoconf defines for mkstemp & putenv instead of
    imake leftovers.
  + install: Use sysconfdir instead of libdir for config files.
  + Add size limit to scanf string specifier.
  + Fix some gcc -Wwrite-strings warnings.
  + Terminate execl() arguments with NULL instead of 0.
  + Convert a couple last sprintf calls to snprintf.
  + Convert XtMalloc + sprintf to XtAsprintf. Depends on libXt >
    1.0.99 to ensure XtAsprintf is available.
  + config:
  - Add missing AC_CONFIG_SRCDIR
  - Replace deprecated AM_CONFIG_HEADER with AC_CONFIG_HEADERS.
  - Replace deprecated AC_HELP_STRING with AS_HELP_STRING.
  - Move man pages into their own directory.
  + man:
  - Replace hard coded man page section with substitution
    strings.
  - Remove trailing spaces and tabs.
  +  Make System() prototype for Solaris in xsm.h actually a
    prototype.
- Drop xsm.diff patch, fixed upstream.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xsm from xorg-x11. Initial version: 1.0.2.
